#!/usr/bin/env node
"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const service_common_1 = require("@crosslab/service-common");
const ws_1 = __importDefault(require("ws"));
const config_1 = require("./config");
const data_source_1 = require("./data_source");
const index_1 = require("./generated/index");
const callbacks_1 = require("./methods/callbacks");
const operations_1 = require("./operations");
data_source_1.AppDataSource.initialize()
    .then(() => {
    index_1.app.use((req, _res, next) => {
        for (const param in req.query) {
            if (typeof req.query[param] == 'string') {
                if (req.query[param] == 'true') {
                    ;
                    req.query[param] = true;
                }
                else if (req.query[param] == 'false') {
                    ;
                    req.query[param] = false;
                }
                else if (req.query[param] == 'undefined') {
                    ;
                    req.query[param] = undefined;
                }
            }
        }
        next();
    });
    index_1.app.initService({
        security: {
            JWT: (0, service_common_1.JWTVerify)(config_1.config)
        },
        additionalHandlers: [
            callbacks_1.callbackHandling
        ]
    });
    const wsServer = new ws_1.default.Server({ noServer: true });
    index_1.app.wsListeners = new Map();
    index_1.app.ws = (path, listener) => index_1.app.wsListeners.set(path, listener);
    (0, operations_1.deviceHandling)(index_1.app);
    const server = index_1.app.listen(config_1.config.PORT);
    server.on('upgrade', async (request, socket, head) => {
        const listener = index_1.app.wsListeners.get(request.url ?? '');
        if (listener) {
            wsServer.handleUpgrade(request, socket, head, (socket) => listener(socket));
        }
    });
})
    .catch((err) => {
    console.error('Error during Data Source initialization:', err);
});
//# sourceMappingURL=index.js.map