"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.deleteDeviceModel = void 0;
const data_source_1 = require("../../data_source");
const model_1 = require("../../model");
const errors_1 = require("../../types/errors");
/**
 * This function attempts to delete a given device model.
 * @param deviceModel The device model to be deleted.
 * @throws {InvalidValueError} Thrown when the given device model does not match any known device type.
 */
async function deleteDeviceModel(deviceModel) {
    if ((0, model_1.isConcreteDeviceModel)(deviceModel)) {
        const concreteDeviceRepository = data_source_1.AppDataSource.getRepository(model_1.ConcreteDeviceModel);
        await concreteDeviceRepository.softDelete(deviceModel.uuid);
    }
    else if ((0, model_1.isDeviceGroupModel)(deviceModel)) {
        const deviceGroupRepository = data_source_1.AppDataSource.getRepository(model_1.DeviceGroupModel);
        await deviceGroupRepository.softDelete(deviceModel.uuid);
    }
    else if ((0, model_1.isInstantiableBrowserDeviceModel)(deviceModel)) {
        const instantiableBrowserDeviceRepository = data_source_1.AppDataSource.getRepository(model_1.InstantiableBrowserDeviceModel);
        await instantiableBrowserDeviceRepository.softDelete(deviceModel.uuid);
    }
    else if ((0, model_1.isInstantiableCloudDeviceModel)(deviceModel)) {
        const instantiableCloudDeviceRepository = data_source_1.AppDataSource.getRepository(model_1.InstantiableCloudDeviceModel);
        await instantiableCloudDeviceRepository.softDelete(deviceModel.uuid);
    }
    else {
        throw new errors_1.InvalidValueError('The device model to be deleted does not match any known device type', 500);
    }
}
exports.deleteDeviceModel = deleteDeviceModel;
//# sourceMappingURL=delete.js.map