"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.findDeviceModelByUUID = void 0;
const data_source_1 = require("../../data_source");
const model_1 = require("../../model");
const errors_1 = require("../../types/errors");
/**
 * This function retrieves a device from the database by its UUID.
 * @param uuid The UUID of the device to be retrieved.
 * @throws {InconsistentDatabaseError} Thrown if device is found as multiple types.
 * @returns The retrieved device.
 */
async function findDeviceModelByUUID(uuid) {
    const concreteDeviceRepository = data_source_1.AppDataSource.getRepository(model_1.ConcreteDeviceModel);
    const deviceGroupRepository = data_source_1.AppDataSource.getRepository(model_1.DeviceGroupModel);
    const instantiableBrowserDeviceRepository = data_source_1.AppDataSource.getRepository(model_1.InstantiableBrowserDeviceModel);
    const instantiableCloudDeviceRepository = data_source_1.AppDataSource.getRepository(model_1.InstantiableCloudDeviceModel);
    const concreteDevice = await concreteDeviceRepository.findOne({
        where: {
            uuid: uuid,
        },
        relations: {
            announcedAvailability: true,
        },
    });
    const deviceGroup = await deviceGroupRepository.findOne({
        where: {
            uuid: uuid,
        },
        relations: {
            devices: true,
        },
    });
    const instantiableBrowserDevice = await instantiableBrowserDeviceRepository.findOne({
        where: {
            uuid: uuid,
        },
        relations: {
            instances: true,
        },
    });
    const instantiableCloudDevice = await instantiableCloudDeviceRepository.findOne({
        where: {
            uuid: uuid,
        },
        relations: {
            instances: true,
        },
    });
    if ((concreteDevice && deviceGroup) ||
        (concreteDevice && instantiableBrowserDevice) ||
        (concreteDevice && instantiableCloudDevice) ||
        (deviceGroup && instantiableBrowserDevice) ||
        (deviceGroup && instantiableCloudDevice) ||
        (instantiableBrowserDevice && instantiableCloudDevice))
        throw new errors_1.InconsistentDatabaseError('Multiple devices found for same uuid');
    if (concreteDevice)
        return concreteDevice;
    if (deviceGroup)
        return deviceGroup;
    if (instantiableBrowserDevice)
        return instantiableBrowserDevice;
    if (instantiableCloudDevice)
        return instantiableCloudDevice;
    return undefined;
}
exports.findDeviceModelByUUID = findDeviceModelByUUID;
//# sourceMappingURL=find.js.map