"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.saveDeviceModel = void 0;
const data_source_1 = require("../../data_source");
const model_1 = require("../../model");
const errors_1 = require("../../types/errors");
/**
 * This function attempts to save a device model in its correct repository.
 * @param deviceModel The device model to be saved.
 */
async function saveDeviceModel(deviceModel) {
    if ((0, model_1.isConcreteDeviceModel)(deviceModel)) {
        await data_source_1.AppDataSource.getRepository(model_1.ConcreteDeviceModel).save(deviceModel);
    }
    else if ((0, model_1.isDeviceGroupModel)(deviceModel)) {
        await data_source_1.AppDataSource.getRepository(model_1.DeviceGroupModel).save(deviceModel);
    }
    else if ((0, model_1.isInstantiableBrowserDeviceModel)(deviceModel)) {
        await data_source_1.AppDataSource.getRepository(model_1.InstantiableBrowserDeviceModel).save(deviceModel);
    }
    else if ((0, model_1.isInstantiableCloudDeviceModel)(deviceModel)) {
        await data_source_1.AppDataSource.getRepository(model_1.InstantiableCloudDeviceModel).save(deviceModel);
    }
    else {
        throw new errors_1.InvalidValueError('The device model to be saved does not match any known device type', 500);
    }
}
exports.saveDeviceModel = saveDeviceModel;
//# sourceMappingURL=save.js.map