"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.handleDeviceMessage = void 0;
const types_1 = require("../generated/types");
const globals_1 = require("../globals");
const errors_1 = require("../types/errors");
const utils_1 = require("./utils");
/**
 * This function handles a signaling message for a device.
 * @param device The device for which to handle the signaling message.
 * @param message The signaling message to be handled.
 */
async function handleSignalingMessage(device, message) {
    const peerconnection = await globals_1.apiClient.getPeerconnection(message.connectionUrl);
    if (!peerconnection.devices)
        throw new errors_1.MissingPropertyError('Peerconnection has no devices');
    const deviceA = peerconnection.devices[0];
    const deviceB = peerconnection.devices[1];
    let peerDeviceUrl;
    if (deviceA.url === (0, utils_1.deviceUrlFromId)(device.uuid)) {
        peerDeviceUrl = deviceB.url;
    }
    else if (deviceB.url === (0, utils_1.deviceUrlFromId)(device.uuid)) {
        peerDeviceUrl = deviceA.url;
    }
    else {
        throw new errors_1.UnrelatedPeerconnectionError('Device is not taking part in peerconnection.');
    }
    if (!peerDeviceUrl)
        throw new errors_1.MissingPropertyError('Peer device is missing its url');
    try {
        await globals_1.apiClient.sendSignalingMessage(peerDeviceUrl, message, message.connectionUrl);
    }
    catch (error) {
        console.error('Something went wrong while trying to send the signaling message:', error);
    }
}
/**
 * This function handles a message for a device.
 * @param device The device for which to handle the message.
 * @param message The message to be handled.
 */
function handleDeviceMessage(device, message) {
    if ((0, types_1.isSignalingMessage)(message)) {
        handleSignalingMessage(device, message);
    }
}
exports.handleDeviceMessage = handleDeviceMessage;
//# sourceMappingURL=messageHandling.js.map