"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.startSignaling = void 0;
const data_source_1 = require("../data_source");
const globals_1 = require("../globals");
const model_1 = require("../model");
const callbacks_1 = require("./callbacks");
const format_1 = require("./database/format");
const utils_1 = require("./utils");
/**
 * This function starts the signaling process for a peerconnection.
 * @param peerconnection The peerconnection the signaling process should be started for.
 * @throws Throws errors of the {@link apiClient.sendSignalingMessage | sendSignalingMessage()} function of the api-client.
 */
async function startSignaling(peerconnection) {
    console.log(`Starting signaling for ${peerconnection.uuid}`);
    const common = {
        messageType: 'command',
        command: 'createPeerconnection',
        connectionType: 'webrtc',
        connectionUrl: (0, utils_1.peerconnectionUrlFromId)(peerconnection.uuid),
    };
    if (peerconnection.status !== "waiting-for-devices") {
        return;
    }
    const createPeerConnectionMessageA = {
        ...common,
        services: peerconnection.deviceA.config
            ? peerconnection.deviceA.config.map(format_1.formatServiceConfig)
            : [],
        tiebreaker: false,
    };
    const createPeerConnectionMessageB = {
        ...common,
        services: peerconnection.deviceB.config
            ? peerconnection.deviceB.config.map(format_1.formatServiceConfig)
            : [],
        tiebreaker: true,
    };
    // TODO: check what problems may occur here and address them accordingly
    await globals_1.apiClient.sendSignalingMessage(peerconnection.deviceA.url, createPeerConnectionMessageA, (0, utils_1.peerconnectionUrlFromId)(peerconnection.uuid));
    await globals_1.apiClient.sendSignalingMessage(peerconnection.deviceB.url, createPeerConnectionMessageB, (0, utils_1.peerconnectionUrlFromId)(peerconnection.uuid));
    // NOTE: this behaviour should maybe be changed later on
    peerconnection.status = 'connected';
    await data_source_1.AppDataSource.getRepository(model_1.PeerconnectionModel).save(peerconnection);
    await (0, callbacks_1.sendStatusChangedCallback)(peerconnection);
}
exports.startSignaling = startSignaling;
//# sourceMappingURL=signaling.js.map