"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.flattenDeviceGroup = exports.resolveDeviceReference = exports.peerconnectionUrlFromId = exports.deviceUrlFromId = void 0;
const config_1 = require("../config");
const globals_1 = require("../globals");
/**
 * This function builds the url of a device using its id.
 * @param deviceÍd The id of the device.
 * @returns The url of the device.
 */
function deviceUrlFromId(deviceÍd) {
    return (config_1.config.BASE_URL +
        (config_1.config.BASE_URL.endsWith('/') ? '' : '/') +
        'devices/' +
        deviceÍd);
}
exports.deviceUrlFromId = deviceUrlFromId;
/**
 * This function builds the url of a peerconnection using its id.
 * @param peerconnectionId The id of the peerconnection.
 * @returns The url of the peerconnection.
 */
function peerconnectionUrlFromId(peerconnectionId) {
    return (config_1.config.BASE_URL +
        (config_1.config.BASE_URL.endsWith('/') ? '' : '/') +
        'peerconnections/' +
        peerconnectionId);
}
exports.peerconnectionUrlFromId = peerconnectionUrlFromId;
/**
 * This function resolves a reference to a device.
 * @param reference The reference to be resolved.
 * @param flat_group If true then the resolved device group will contain no further device groups.
 * @returns The resolved device.
 */
async function resolveDeviceReference(reference, flat_group = false) {
    if (reference.url) {
        const deviceId = reference.url.split('/').at(-1);
        if (!deviceId)
            return undefined;
        console.log('resolving device', reference.url, config_1.config.BASE_URL);
        try {
            return await globals_1.apiClient.getDevice(reference.url, { flat_group });
        }
        catch (error) {
            return undefined;
        }
    }
    return undefined;
}
exports.resolveDeviceReference = resolveDeviceReference;
/**
 * This function flattens a device group.
 * @param deviceGroup The device group to be flattened
 * @returns The device group containing only concrete devices.
 */
function flattenDeviceGroup(deviceGroup) {
    const devices = [];
    if (deviceGroup.devices) {
        for (const device of deviceGroup.devices) {
            if (!device.type)
                continue;
            if (device.type == 'device')
                devices.push(device);
            if (device.type == 'edge instantiable')
                devices.push(device);
            if (device.type == 'cloud instantiable')
                devices.push(device);
            if (device.type == 'group')
                devices.push(...flattenDeviceGroup(device));
        }
    }
    return devices;
}
exports.flattenDeviceGroup = flattenDeviceGroup;
//# sourceMappingURL=utils.js.map