"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.MalformedBodyError = exports.JWTVerificationError = exports.DeviceNotConnectedError = exports.InvalidChangeError = exports.InconsistentDatabaseError = exports.InvalidValueError = exports.ForbiddenOperationError = exports.UnrelatedPeerconnectionError = exports.MissingPropertyError = exports.MissingEntityError = void 0;
const types_1 = require("../generated/types");
/**
 * This error class should be used if an entity is not found in the database.
 */
class MissingEntityError extends types_1.ErrorWithStatus {
    constructor(message, status) {
        super(message, status);
        this.name = 'MissingEntityError';
    }
}
exports.MissingEntityError = MissingEntityError;
/**
 * This error class should be used if an object is missing a needed property.
 */
class MissingPropertyError extends types_1.ErrorWithStatus {
    constructor(message, status) {
        super(message, status);
        this.name = 'MissingPropertyError';
    }
}
exports.MissingPropertyError = MissingPropertyError;
/**
 * This error class should be used if a device is not related to a peerconnection.
 */
class UnrelatedPeerconnectionError extends types_1.ErrorWithStatus {
    constructor(message, status) {
        super(message, status);
        this.name = 'UnrelatedPeerconnectionError';
    }
}
exports.UnrelatedPeerconnectionError = UnrelatedPeerconnectionError;
/**
 * This error class should be used if an object is missing a needed property.
 */
class ForbiddenOperationError extends types_1.ErrorWithStatus {
    constructor(message, status) {
        super(message, status);
        this.name = 'ForbiddenOperationError';
    }
}
exports.ForbiddenOperationError = ForbiddenOperationError;
/**
 * This error class should be used if an object contains an invalid value.
 */
class InvalidValueError extends types_1.ErrorWithStatus {
    constructor(message, status) {
        super(message, status);
        this.name = 'InvalidValueError';
    }
}
exports.InvalidValueError = InvalidValueError;
/**
 * This error class should be used if there is an inconsistency in the database.
 */
class InconsistentDatabaseError extends types_1.ErrorWithStatus {
    constructor(message, status) {
        super(message, status);
        this.name = 'InconsistentDatabaseError';
    }
}
exports.InconsistentDatabaseError = InconsistentDatabaseError;
/**
 * This error class should be used if the user attempts an invalid change.
 */
class InvalidChangeError extends types_1.ErrorWithStatus {
    constructor(message, status) {
        super(message, status);
        this.name = 'InvalidChangeError';
    }
}
exports.InvalidChangeError = InvalidChangeError;
/**
 * This error class should be used if a required device is not connection.
 */
class DeviceNotConnectedError extends types_1.ErrorWithStatus {
    constructor(message, status) {
        super(message, status);
        this.name = 'DeviceNotConnectedError';
    }
}
exports.DeviceNotConnectedError = DeviceNotConnectedError;
/**
 * This error class should be used if an error occurs during JWT verification.
 */
class JWTVerificationError extends types_1.ErrorWithStatus {
    constructor(message, status) {
        super(message, status);
        this.name = "JWTVerificationError";
    }
}
exports.JWTVerificationError = JWTVerificationError;
/**
 * This error class should be used if the body of a request is malformed.
 */
class MalformedBodyError extends types_1.ErrorWithStatus {
    constructor(message, status) {
        super(message, status);
        this.name = "MalformedBodyError";
    }
}
exports.MalformedBodyError = MalformedBodyError;
//# sourceMappingURL=errors.js.map